==> kdesvn-1.7.0.tar.xz: kdesvn-1.7.0/src/ksvnwidgets/depthselector.h <==
/***************************************************************************
 *   Copyright (C) 2007 by Rajko Albrecht  ral@alwins-world.de             *
 *   http://kdesvn.alwins-world.de/                                        *
 *                                                                         *
 *   This program is free software; you can redistribute it and/or modify  *
 *   it under the terms of the GNU General Public License as published by  *
 *   the Free Software Foundation; either version 2 of the License, or     *
 *   (at your option) any later version.                                   *
 *                                                                         *
 *   This program is distributed in the hope that it will be useful,       *
 *   but WITHOUT ANY WARRANTY; without even the implied warranty of        *
 *   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the         *
 *   GNU General Public License for more details.                          *
 *                                                                         *
 *   You should have received a copy of the GNU General Public License     *
 *   along with this program; if not, write to the                         *
 *   Free Software Foundation, Inc.,                                       *
 *   51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA.         *
 ***************************************************************************/
#ifndef DEPTHSELECTOR_H
#define DEPTHSELECTOR_H

#include "src/ksvnwidgets/ui_depthform.h"

#include "src/svnqt/svnqttypes.h"

class QCheckBox;

class DepthSelector: public QWidget, Ui::DepthForm
{
    Q_OBJECT
public:
    explicit DepthSelector(QWidget *parent = 0);
    virtual ~DepthSelector();
    svn::Depth getDepth()const;
    void addItemWidget(QWidget *);
    void hideDepth(bool hide);
    void setRecursive(bool rec);

protected:
    QCheckBox *m_recurse;
};

#endif

==> kdesvn_2.0.0.orig.tar.xz: kdesvn-2.0.0/src/ksvnwidgets/depthselector.h <==
/***************************************************************************
 *   Copyright (C) 2007 by Rajko Albrecht  ral@alwins-world.de             *
 *   http://kdesvn.alwins-world.de/                                        *
 *                                                                         *
 *   This program is free software; you can redistribute it and/or modify  *
 *   it under the terms of the GNU General Public License as published by  *
 *   the Free Software Foundation; either version 2 of the License, or     *
 *   (at your option) any later version.                                   *
 *                                                                         *
 *   This program is distributed in the hope that it will be useful,       *
 *   but WITHOUT ANY WARRANTY; without even the implied warranty of        *
 *   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the         *
 *   GNU General Public License for more details.                          *
 *                                                                         *
 *   You should have received a copy of the GNU General Public License     *
 *   along with this program; if not, write to the                         *
 *   Free Software Foundation, Inc.,                                       *
 *   51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA.         *
 ***************************************************************************/
#pragma once

#include <QWidget>
#include "svnqt/svnqttypes.h"

namespace Ui
{
class DepthSelector;
}

class DepthSelector: public QWidget
{
    Q_OBJECT
public:
    explicit DepthSelector(QWidget *parent = nullptr);
    virtual ~DepthSelector();

    svn::Depth getDepth() const;
    void addItemWidget(QWidget *);
    void hideDepth(bool hide);

private:
    Ui::DepthSelector *m_ui;
};
